#!/usr/bin/php -q
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id$


/**
  * A CLI tool to validate the maintain configuration file, maintain.cfg
  *
  * @package    bin
  */

require_once dirname(__FILE__).'/includes.php';

/* Setup the array of command-line values */
$validargs = array(
        'inputfile' => array( 'short' => 'i',
                        'min' => 1,
                        'max' => 1,
                        'desc' => _("Full path to the config file to validate")
                    ),
        'outputfile' => array( 'short' => 'o',
                        'min' => 1,
                        'max' => 1,
                        'desc' => _("Full path to write config to if valid")
                    ),
        'force' => array( 'short' => 'f',
                    'max' => 0,
                    'desc' => _("Write the new config file without prompting")
                    )
        );

// set up the executable
$bin = new MaintainBin($validargs);

// parse the input
$args = $bin->parseArgs();

// make sure 'inputfile' was specified
if (!$args->getValue('inputfile')) {
    $msg = _("You must specify the input file") . "\n";
    
    $fullmsg = Console_Getargs::getHelp($validargs, $msg);
    $bin->fail($fullmsg);
}

// create a tree based on the config file
// THIS IS BROKEN SINCE WE CAN'T VALIDATE ANYMORE!
return true;
$conftree = parse_ini_file(CONFIG, true);

// if the config is invalid, display a list of errors and exit
if(is_array($conftree->validate())) {
    $msg = "\n";
    $msg .= _("The following errors were found in")." $infile\n";

    foreach($valid as $error)
        $msg .= "\t$error\n";

    $bin->fail($msg);

}

// if they didn't ask for an output file, or if the output file is the same
// as the input file, exit successfully
if (!$args->isDefined('outputfile') || 
    $args->getValue('outputfile') == $args->getValue('inputfile')) {

    // set up exiting message
    $msg = _("Config file").' '. $args->getValue('inputfile')  .' '._("is valid");

    // successfully terminate the script
    $bin->finish($msg);
}

// if write isn't forced, make sure they really want to write it
if (!$args->isDefined('force')) {
    $prompt = _("Would you like to write this information to file").
        " $outfile"._("? (Yes/No/Quit):")." ";

    $force = prompt($prompt);
}

// if they don't want to write the file, we're done
if (!$force) {

    $msg = _("Config file").' '.$args->getValue('inputfile').' '._("is valid");

    $bin->finish($msg);
}

// the config is valid, write it to the output file
write($conftree->toArray(), $outfile);

/*******************************
********** Functions ***********
*******************************/

// {{{ prompt()

/**
  * Given a prompt string, read user input, 
  * standardize the response, and validate it
  *
  * A value of q/quit/Q/Quit exits the script with SUCCESS status
  *
  * @access private
  * @param  string  prompt to display to user
  * @return bool    returns true if response is Y/y/yes/Yes
  */
function prompt($prompt) 
{
    // define the set of valid responses
    $yes    = array('y', 'yes');
    $no     = array('n', 'no');
    $quit   = array('q', 'quit');

    // test that input is one of yes/y/n/no
    $valid = false;

    while (!$valid) {

        // display the prompt
        echo "\n$prompt";

        // open up standard in for reading
        $in = fopen("php://stdin","r");

        // remove whitespace and lower-case the response
        $res = strtolower(trim(fgets($in,4)));

        if (in_array($res, $yes))
            return true;

        elseif (in_array($res, $no))
            return false;

        elseif (in_array($res, $quit))
            exit(SUCCESS);

        // otherwise, should just return to top of while loop
    }

    // we shouldn't get here...but just in case
    return false;

}

// }}}
// {{{ write()

/**
  * Attempt to write the config to:
  *     1) the specified location
  *     2) /tmp
  *     3) keep prompting the user until a valid path is given
  *
  * @acces  private
  * @param  array   Config array
  * @param  string  path to write config to
  */
function write($config, $file) 
{

    // attempt to write to specified location
    if(writeConfig($config, $file))
        write_success($file);

    /* if writing has failed, keep prompting the user
     * until a writeable path is chosen, or they quit
     */
    $quit = array('q', 'quit');
    $success = false;

    while (!$success) {
        $msg .= "\n$file "._("is not writeable")."\n";
        $msg .= _("Please enter a path to write the config to")."\n";
        $msg .= _("(You may enter 'q' or 'quit' at any time to exit this program):").' ';

        echo $msg;
        unset($msg);

        // open up STDIN for reading
        $in = fopen('php://stdin', 'r');

        // strip whitespace
        $file = trim(fgets($in));

        // quit if they want
        if (in_array(strtolower($file), $quit))
            exit(ERROR);

        $success = writeConfig($config, $file);
    }

    // if we got here, we were successful
    write_success($file);

} //write

// }}}
// {{{ usage()

/**
  * Output the proper usage of this script
  *
  * @access private
  * @global array   array of arguments passed to this script
  * @param  string  additional string to output to user
  */
function usage($msg) {
    global $args;

    // define the script (as called)
    $script = $args[0];

    $usage = <<<STR

$msg

Available options:

    -h, --help              print this message
    -i, --inputfile=PATH    path of config file to validate
    -o, --outputfile=PATH   path to write config to if valid
    -f, --force             attempts to write the new config without prompting for confirmation

examples:

    $script -i config/maintain.cfg -o /home/user/tmp/valid_config.txt
    $script --inputfile /tmp/test_config.ini -o /maintain/config/maintain.cfg --force


STR;

    echo($usage);
    exit(ERROR);
} //usage

// }}}
// {{{ write_success()

/**
  * Inform the user of a successful write and return status code SUCCESS
  *
  * @global object  MaintainBin object
  * @param  string  path of file written to
  */
function write_success($file) 
{
    global $bin;

    $msg = _("Config successfully written to")." $file\n";
    $bin->finish($msg);

} //write_success

// }}}

?>
