<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/tags/release-3.0.0-RC2/class/dao/extended/workgroup.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: workgroup.php 4533 2006-06-26 23:52:30Z wenzel $

/**
  * workgroup.php - contains the {@link Workgroup} class
  *
  * @author $Author: wenzel $
  * @filesource
  * @package    classes
  * @subpackage dao
  */

include_once DAODIR.'/Workgroup.php';

/**
  * A workgroup is a DHCP Group. Each host can have a workgroup definition 
  * associated with it and it allows us to set per-host DHCP options as well
  * as dynamic VLAN settings.
  *
  * @package    classes
  * @subpackage dao
  */
class Workgroup extends DAO_Workgroup {

    // {{{ constructor

    /**
      * Constructor
      *
      * @param  int ID of workgroup (primary key in DB)
      */
    function Workgroup( $workgroup_id = 0) 
    {

        if ($workgroup_id) {
            $this->id = $workgroup_id;
            $this->get($this->id);
        }

    } // Workgroup

    // }}}

/* DBDO Overloads */
    // {{{ delete()

    /**
      * Overloaded to handle related items, such as object_option and zone_workgroup
      */
    function delete($useWhere = false) 
    {
        // delete the workgroup itself
        $result = parent::delete();

        if (!$result)
            return $result;

        // Delete any option assoicated with it
        // "DELETE FROM object_option WHERE type='workgroup' AND object_id='$this->id'";
        $dbdo = DB_DataObject::Factory('object_option');
        $dbdo->type = 'workgroup';
        $dbdo->object_id = $this->id;
        $dbdo->delete();

        // Delete any workgroup --> zone records
        // "DELETE FROM zone_workgroup WHERE workgroup='$this->id'";
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->workgroup = $this->id;
        $dbdo->delete();

        return $result;

    } //delete

    // }}}

/* Internal Methods */
    // {{{ get_options()

    /**
      * Get the local options for this object
      *
      * @return array   integer array of Option IDs (primary keys)
      */
    function get_options() 
    {
       global $conf;

        // "SELECT * FROM object_option WHERE object_id=$this->id AND type='workgroup'"
        $dbdo = DB_DataObject::Factory('object_option');
        $dbdo->object_id = $this->id;
        $dbdo->type = 'workgroup';
        $dbdo->find();

        while ($dbdo->fetch()) {
            $options[] = $dbdo->id;
        }

        return $options;

    } // get_options

    // }}}
    // {{{ get_ranges()

    /**
      * Get the ranges that this workgroup is allowed to be used in
      *
      * Note: This function will NEVER work!  It references this class'
      * subnet variable which doesn't exist and never gets defined.
      * 
      * @return array   array of IDs for the Ranges table meeting the criteria
      */
    function get_ranges() 
    {
        if (!$this->subnet)
            return array();

        // "SELECT id FROM ranges WHERE subnet=". $this->subnet->id;
        $dbdo = DB_DataObject::Factory('ranges');
        $dbdo->subnet = $this->subnet;
        $dbdo->find();

        $ranges = array();
        while ($dbdo->fetch()) 
            $ranges[] = $dbdo->id;

        return $ranges;

    } // get_ranges

    // }}}
    // {{{ has_zone

    /**
      * Check that this workgroup is allowed in the specified zone
      *
      * @param  int     Zone ID (primary key)
      * @return bool    true if workgroup has a mapping to given zone
      */
    function has_zone($zone_id) 
    {
        // "SELECT * FROM zone_workgroup WHERE workgroup='$this->id' AND zone='$zone_id'";
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->workgroup = $this->id;
        $dbdo->zone = $zone_id;

        return ($dbdo->find()) ? true : false;

    } // has_zone

    // }}}
    // {{{ has_access()

    /**
      * Check that given user has at least zone_admin access to this workgroup
      *
      * @param  string  username to query for
      * @return boolean true if user has >zone_admin access to this workgroup
      */
    function has_access($username) 
    {
        
        //"SELECT * FROM zone_user,zone_workgroup WHERE 
        //zone_workgroup.workgroup='$this->id' AND zone_user.username='$username' 
        //AND zone_user.zone=zone_workgroup.zone AND zone_user.level >='50'";

        $user   = DB_DataObject::Factory('zone_user');
        $user->username = $username;
        $user->whereAdd("level>='".ZONE_ADMIN."'");
        
        $wkp    = DB_DataObject::Factory('zone_workgroup');
        $wkp->workgroup = $this->id;

        $user->joinAdd($wkp);

        return ($user->find()) ? true : false;

    } // has_access

    // }}}
    // {{{ is_default()

    /**
      * Test if this workgroup is the default workgroup for specified zone
      *
      * @param  int     Zone ID
      * @return boolean true if workgroup is the default for said zone
      */
    function is_default($zone_id) 
    {
        // "SELECT is_default FROM zone_workgroup WHERE zone='$zone_id' AND workgroup='$this->id'";
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->selectAdd();
        $dbdo->selectAdd('is_default');
        $dbdo->zone = $zone_id;
        $dbdo->workgroup = $this->id;

        if ($dbdo->find(true)) {
            return $dbdo->is_default;
        } else {
            return false;
        }

    } // is_default

    // }}}
    // {{{ add_zone()

    /**
      * Add a zone_workgroup mapping for this workgroup
      *
      * @param  int     Zone ID
      * @param  boolean whether this is the default workgroup for this zone
      * @return boolean true on successful addition
      */
    function add_zone($zone_id,$default = false)
    {
        // Check to make sure it isn't in there already...
        // "SELECT id FROM zone_workgroup WHERE workgroup='$this->id' AND zone='$zone_id'";
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->workgroup = $this->id;
        $dbdo->zone = $zone_id;

        if ($dbdo->find()) {
            return false;
        }

        // convert $default to MySQL smallint
        $default = ($default) ? 1 : 0;

        // "INSERT INTO zone_workgroup (zone,workgroup,is_default) VALUES ('$zone_id','$this->id','$default')";
        $dbdo->is_default = $default;

        if ($dbdo->insert()) {
            return true;
        }

        return false;

    } // add_zone

    // }}}
    // {{{ make_default() (deprecated)

    /**
      * Force this workgroup to be the default for specified zone
      *
      * @deprecated only called once, just call these lines directly
      * @param  int     Zone ID
      * @return boolean true on success
      */
    function make_default($zone_id)
    {
        // "UPDATE zone_workgroup SET is_default='$default' WHERE workgroup='$this->id' AND zone='$zone_id'";
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->is_default = 1;
        $dbdo->whereAdd("workgroup='{$this->id}'");
        $dbdo->whereAdd("zone='$zone_id'");
        $dbdo->update(DB_DATAOBJECT_WHEREADD_ONLY);

        // make sure nothing else is the default
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->is_default   = 0;
        $dbdo->whereAdd("workgroup!='$this->id'");
        $dbdo->whereAdd("zone='$zone_id'");
        $dbdo->update(DB_DATAOBJECT_WHEREADD_ONLY);

    } // make_default

    // }}}
    // {{{ delete_zone() (deprecated)

    /**
      * Delete a zone_workgroup mapping
      *
      * @deprecated     use standard DBDO methods
      * @param  int     Zone ID to delete
      * @return mixed   number of rows deleted, false on failure
      */
    function delete_zone($zone_id) 
    {
        // Delete the record
        // "DELETE FROM zone_workgroup WHERE zone='$zone_id' AND workgroup='$this->id'";
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->zone = $zone_id;
        $dbdo->workgroup = $this->id;
        return $dbdo->delete();

    } // delete_zone

    // }}}

/* Validators */
    // {{{ validateName()

    function validateName()
    {
        global $conf;

        // make sure a valid DHCP group name is given
        if (!ereg("^[[:alnum:]\-\.[:space:]]+$", $this->name))
            return _("Workgroup names can only contain alphanumerics, '-' and '.'");

        // make sure this isn't a duplicate workgroup

        // "SELECT * FROM workgroup WHERE name LIKE '$name'";
        $dbdo = DB_DataObject::Factory('workgroup');
        $dbdo->whereAdd("name LIKE '$name'");
        if ($this->id)
            $dbdo->whereAdd("id!='$this->id'");

        if ($dbdo->find())
            return _("Workgroup name already found");

        return true;

    } // check_name

    // }}}

/* Maintain Overloads */
    // {{{ _history_text()
    function _history_text()
    {
        // : WORKGROUP
        return $this->getName();
    }
    // }}}

}

?>
