<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: SubnetCreateForm.php 4661 2006-07-25 18:06:24Z schonstal $

/**
 *  SubnetCreateForm.php - contains the {@link SubnetCreateForm} class
 *
 *  @author $Author:$
 *  @package    htdocs  
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This class is the form that is used to create a new Subnet object
 *
 *  @package    htdocs
 *  @subpackage forms
 */ 
class SubnetCreateForm extends MaintainForm
{

//{{{   vars

    /**
     *  This array maps form labels to DBDO vars and vice verse
     */
    var $map = array("Name"=>"name",
                    "Subnet"=>"subnet",
                    "Netmask"=>"netmask",
                    "VLAN"=>"vlan",
                    "Status"=>"status");

//}}}

//{{{   form_init_elements()

    /**
     *  This method is responsible for intializing the form elements that are going
     *  to be displayed and filled in by the user.
     */
    function form_init_elements() 
    {
        $name = new FEText(_("Name"), true);
        $subnet = new FEText(_("Subnet"), true);
        $netmask = new FEText(_("Netmask"), true);
        $usevlan = new FECheckBox(_("Add to Vlan"));
        $vlan = new FEListBox(_("VLAN"), false);
        $status = new FEListBox(_("Status"));
        $comment = new FETextArea(_("Comment"),true, 5, 40);
        
        $vlan->set_list_data($this->_vlans());
        $status->set_list_data(array("Visible"=>"visible",
                                    "Hidden"=>"hidden"));

        $this->add_elements($name, $subnet, $netmask, $usevlan, $vlan, $status, $comment);
    }

//}}}
//{{{   form_init_data()

    /**
     *  This method just sets the initial form values for certain fields.
     */
    function form_init_data()
    {
        $this->set_element_value(_("Subnet"),"0.0.0.0");
        $this->set_element_value(_("Netmask"),"0.0.0.0");
        $this->set_element_value(_("Comment"),"Created Subnet");
    }

//}}}
//{{{   form_backend_validation()

    /**
     *  This method validares the form values to see if they are suitable to be
     *  used in the form action.
     *
     *  @return Boolean     True if the data is valid
     */
    function form_backend_validation()
    {
        $res = true;
        
        $vals = $this->get_all_element_values();
        
        // don't care about the VLAN if checkbox not checked
        if(!isset($vals[_('Add to Vlan')])) {
            $vals[_("VLAN")] = 0;
        }
        
        $subn = new Subnet($_REQUEST['id']);
        $subn->setFrom($this->remap($vals,DBDO));

        $valid = $subn->validate();

        if($valid !== true) {
            $errors = $this->remap($valid, FORM);
            $res = false;

            foreach($errors as $label=>$error) {
                if($error !== true)
                    $this->add_error($label, $error);
            }
        }

        return $res;
    }

//}}}
//{{{   form_action()

    function form_action()
    {
        global $user;

        switch(strtolower($this->get_action())) {

        case 'submit':
            $res = true;
            $vals = $this->get_all_element_values();
        
            $subn = new Subnet();
            $subn->query("BEGIN");

            if(!isset($vals[_('Add_to_Vlan')])) {
                $vals[_("VLAN")] = 0;
            }

            $subn->setFrom($this->remap($vals, DBDO));

            if(!$subn->insert()) {
                $subn->query("ROLLBACK");
                $res = false;
                $this->add_error(_("ERROR"),_("Couldn't add subnet to database"));
            } else {
                $subn->query("COMMIT");
                $subn->write_history($vals[_("Comment")], ACTION_CREATE, $user->username);
            }
            return $res;
            break;

        default:
            die_hard(_("Invalid form action"));
            break;
        }
    }

//}}}
//{{{   form_success()

    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php", _("[Return to Index]"));
        $sublink = html_a(web_root()."subnet.php",_("[Return to Subnet List]"));
        $div->add(_("Subnet successfully created!"),html_br());
        $div->add($indlink, $sublink);

        return $div;
    }

//}}}

//{{{   _vlans()

    /**
     *  This is a helper method that is used to populate the vlans listbox
     *
     *  @return Array   $vlans  An array of vlans indexed by name
     */
    function _vlans()
    {
        $vlans = array();
        
        $vlan = DB_DataObject::Factory('vlan');
        $vlan->orderBy("name ASC");
        $vlan->find();
        
        while($vlan->fetch())
            $vlans[$vlan->name] = $vlan->id;

        return $vlans;
    }

//}}}

}

?>
