<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Zack Bartel <bartel@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: ZoneWorkgroupAddForm.php 4082 2006-01-10 17:50:59Z bartel $

require_once(FORMDIR."/MaintainForm.php");

/* This class handles adding workgroups to a zone from the zone's perspective */

class ZoneWorkgroupAddForm extends MaintainForm
{

/*Vars*/
//{{{   vars

    /**
     *  Maps form values to DBDO values
     */
    var $map = array('Add_Workgroup' => 'workgroup',
                    'Make_Default' => 'is_default');

//}}}

/*Methods*/
//{{{   form_init_elements()

    /**
     *  This method initializes the elements of the form
     */
    function form_init_elements()
    {
        $def = new FECheckbox(_("Make Default"));
        $zones = new FEListBox(_("Add Workgroup"));

        $ary = $this->_workgroups();

        $zones->set_list_data($ary);

        $this->add_elements($zones, $def);
    }

//}}}
//{{{   form_action()
    
    /**
     *  This method is what actually processes the form request and makes the
     *  appriopriate database queries.
     *
     *  @return Boolean True if action is successful
     */
    function form_action() 
    {
        global $user;
        $res = true;
        
        switch(strtolower($this->get_action())) {
        
        case 'submit':
            $vals = $this->get_all_element_values();
            if(!isset($vals[_('Make_Default')]))
                $vals[_('Make_Default')] = 0;
            $ary = $this->remap($vals, DBDO);
            $zw = DB_DataObject::Factory('zone_workgroup');
            $zw->query("BEGIN");
            $zw->setFrom($ary);
            $zw->zone = $_REQUEST['id'];
            if(!$zw->insert()) {
                $zw->query("ROLLBACK");
                $this->add_error(_('ERROR'),_('Failed to insert into DB'));
                $res = false;
            } else {
                $zw->query("COMMIT");
                $zw->write_history(_("Workgroup added to Zone"), ACTION_MODIFY,
                                    $user->username, $zw->zone);

                //If this is supposed to be the default we need to clear the old one
                if($vals[_('Make_Default')] == 1) {
                    $reqid = $_REQUEST['id'];
                    $dbdo = DB_DataObject::Factory('zone_workgroup');
                    $dbdo->query("BEGIN");
                    $dbdo->is_default = 0;
                    $dbdo->whereAdd("workgroup!='$zw->workgroup'");
                    $dbdo->whereAdd("zone='$zw->zone'");
                    if($dbdo->update(DB_DATAOBJECT_WHEREADD_ONLY) !== false) {
                        $dbdo->query("COMMIT");
                        $dbdo->write_history(_("Default Workgroup for Zone Set"),
                                            ACTION_MODIFY, $user->username, $zw->zone);
                    } else {
                        $dbdo->query("ROLLBACK");
                        $this->add_error(_("ERROR"),_("Failed to make workgroup default"));
                        $res = false;
                    }
                    
                }
                
            }
            break;

        default:
            $this->add_error(_("ERROR"), _("Unknown form action"));
            break;
            
        }
        
        return $res;
    }

//}}}
//{{{   form_hidden()

    /**
     *  This method adds the hidden elements to the form to retain some necessary
     *  information such as the action and ID for the object we're working with.
     *
     *  @return Container   Container with hidden elements inside
     */
    function form_hidden() 
    {
        $action = new FEHidden("action","edit");
        $objid = new FEHidden("id",$_REQUEST['id']);

        $this->add_elements($objid, $action);

        return container($this->element_form("id"), $this->element_form("action"));
    }

//}}}

//{{{ form_backend_validation()
    /**
     *
     *  Function to validate Zone to be added to the Workgroup.
     *  In this case all we are checking for is that the 
     *  relationship doesn't already exist.
     */
    function form_backend_validation()
    {
        $zw = DB_DataObject::Factory('zone_workgroup');
        $zw->zone = $_REQUEST['id'];
        $zw->workgroup = $this->get_element_value('Add Workgroup'); 
        $zw->find();
        if ($zw->fetch())   {
            $this->add_error(_("ERROR"), _("This workgroup already exist in this zone"));
            return false;
        }
        return true;
    }

//}}}
/*Helper Methods*/
//{{{   _workgroups()

    /**
     *  Helper method to generate an array to fill up the Workgroup List Box
     *
     *  @return Array   $ary    Array of workgroups indexed by name
     */
    function _workgroups()
    {
        global $user;
        $ary = array();

        $zn = DB_DataObject::Factory('workgroup');
        $zn->orderBy('name ASC');
        $zn->find();

        while($zn->fetch()) {
            $ary[$zn->name] = $zn->id;
        }
        
        return $ary;
    }

//}}}

}

?>
